@@ -297,7 +297,7 @@ class LcovCoverageReporter(BaseViolationReporter):
             # we're only interested in file name and line coverage
             if directive == "SF":
                 # SF:<absolute path to the source file>
-                source_file = content
+                source_file = util.to_unix_path(GitPathTool.relative_path(content))
                 continue
             elif directive == "DA":
                 # DA:<line number>,<execution count>[,<checksum>]
